AirPlace

Struct AirPlace 

pub struct AirPlace {
    pub base: AirPlaceBase,
    pub projections_start: u32,
    pub projections_len: u32,
}
A memory location that can be read from or written to.

A place represents a path to a memory location, consisting of a base (local variable or parameter) and zero or more projections (field access, array indexing).

Examples

  • xAirPlace { base: Local(0), projections_start: 0, projections_len: 0 }
  • arr[i]AirPlace { base: Local(0), ... } with Index projection
  • point.xAirPlace { base: Local(0), ... } with Field projection
  • arr[i].xAirPlace { base: Local(0), ... } with Index then Field

Fields

base: AirPlaceBase

The base of the place - either a local slot or parameter slot

projections_start: u32

Start index into Air’s projections array

projections_len: u32

Number of projections

Implementations

Source

impl AirPlace

pub const fn local(slot: u32) -> Self

Create a place for a local variable with no projections.

pub const fn param(slot: u32) -> Self

Create a place for a parameter with no projections.

pub const fn is_simple(&self) -> bool

Returns true if this place has no projections (is just a variable).

pub const fn as_local(&self) -> Option<u32>

Returns the local slot if this is a simple local place with no projections.

pub const fn as_param(&self) -> Option<u32>

Returns the param slot if this is a simple param place with no projections.