pub struct ArrayTypeId(pub u32);Expand description
A unique identifier for an array type.
This is needed because Type is Copy, so we can’t use Box
Tuple Fields
0: u32Implementations
Sourceimpl ArrayTypeId
impl ArrayTypeId
Sourcepub fn from_pool_index(pool_index: u32) -> Self
pub fn from_pool_index(pool_index: u32) -> Self
Create an ArrayTypeId from a pool index.
This is used during Phase 2B to create ArrayTypeIds from pool indices.
The pool index is the raw index into TypeInternPool.types.
Sourcepub fn pool_index(self) -> u32
pub fn pool_index(self) -> u32
Get the pool index for this array type.
Returns the raw index into the TypeInternPool.