pub struct EnumId(pub u32);Expand description
A unique identifier for an enum definition.
As of Phase 3 (ADR-0024), the inner value is a pool index into TypeInternPool,
not a vector index into a separate enum definitions array.
Tuple Fields
0: u32Implementations
Sourceimpl EnumId
impl EnumId
Sourcepub fn from_pool_index(pool_index: u32) -> Self
pub fn from_pool_index(pool_index: u32) -> Self
Create an EnumId from a pool index.
This is the primary way to create EnumIds during Phase 3+.
The pool index is the raw index into TypeInternPool.types.
Sourcepub fn pool_index(self) -> u32
pub fn pool_index(self) -> u32
Get the pool index for this enum.
This is the index into TypeInternPool.types.