pub struct PtrConstTypeId(pub u32);Expand description
A unique identifier for a ptr const T type.
This is needed because Type is Copy, so we can’t use Box
Tuple Fields
0: u32Implementations
Sourceimpl PtrConstTypeId
impl PtrConstTypeId
Sourcepub fn from_pool_index(pool_index: u32) -> Self
pub fn from_pool_index(pool_index: u32) -> Self
Create a PtrConstTypeId from a pool index.
Sourcepub fn pool_index(self) -> u32
pub fn pool_index(self) -> u32
Get the pool index for this pointer type.