pub struct PtrMutTypeId(pub u32);Expand description
A unique identifier for a ptr mut T type.
This is needed because Type is Copy, so we can’t use Box
Tuple Fields
0: u32Implementations
Sourceimpl PtrMutTypeId
impl PtrMutTypeId
Sourcepub fn from_pool_index(pool_index: u32) -> Self
pub fn from_pool_index(pool_index: u32) -> Self
Create a PtrMutTypeId from a pool index.
Sourcepub fn pool_index(self) -> u32
pub fn pool_index(self) -> u32
Get the pool index for this pointer type.