pub struct StructId(pub u32);Expand description
A unique identifier for a struct definition.
As of Phase 3 (ADR-0024), the inner value is a pool index into TypeInternPool,
not a vector index into a separate struct definitions array.
Tuple Fields
0: u32Implementations
Sourceimpl StructId
impl StructId
Sourcepub fn from_pool_index(pool_index: u32) -> Self
pub fn from_pool_index(pool_index: u32) -> Self
Create a StructId from a pool index.
This is the primary way to create StructIds during Phase 3+.
The pool index is the raw index into TypeInternPool.types.
Sourcepub fn pool_index(self) -> u32
pub fn pool_index(self) -> u32
Get the pool index for this struct.
This is the index into TypeInternPool.types.