pub struct AirPlace {
pub base: AirPlaceBase,
pub projections_start: u32,
pub projections_len: u32,
}Expand description
A memory location that can be read from or written to.
A place represents a path to a memory location, consisting of a base (local variable or parameter) and zero or more projections (field access, array indexing).
Examples
x→AirPlace { base: Local(0), projections_start: 0, projections_len: 0 }arr[i]→AirPlace { base: Local(0), ... }withIndexprojectionpoint.x→AirPlace { base: Local(0), ... }withFieldprojectionarr[i].x→AirPlace { base: Local(0), ... }withIndexthenField
Fields
base: AirPlaceBaseThe base of the place - either a local slot or parameter slot
projections_start: u32Start index into Air’s projections array
projections_len: u32Number of projections
Implementations