pub struct InternedType(/* private fields */);Expand description
Interned type index - 32 bits, Copy, cheap comparison.
Reserved indices 0-15 are primitives (no lookup needed). Index 16+ are composite types stored in the pool.
Primitive Encoding
The following indices are reserved for primitive types:
- 0: i8
- 1: i16
- 2: i32
- 3: i64
- 4: u8
- 5: u16
- 6: u32
- 7: u64
- 8: isize
- 9: usize
- 10: f16
- 11: f32
- 12: f64
- 13: bool
- 14: unit
- 15: never
- 16: error
- 17-18: reserved for future primitives
Implementations
Sourceimpl InternedType
impl InternedType
pub const I8: InternedType
pub const I16: InternedType
pub const I32: InternedType
pub const I64: InternedType
pub const U8: InternedType
pub const U16: InternedType
pub const U32: InternedType
pub const U64: InternedType
pub const ISIZE: InternedType
pub const USIZE: InternedType
pub const F16: InternedType
pub const F32: InternedType
pub const F64: InternedType
pub const BOOL: InternedType
pub const UNIT: InternedType
pub const NEVER: InternedType
pub const ERROR: InternedType
Sourcepub fn is_primitive(self) -> bool
pub fn is_primitive(self) -> bool
Check if this is a primitive type (no pool lookup needed).
Sourcepub fn from_raw(index: u32) -> Self
pub fn from_raw(index: u32) -> Self
Create an InternedType from a raw index.
Safety
The caller must ensure the index is valid (either a primitive index 0-15, or a composite index that exists in the pool).
Sourcepub fn pool_index(self) -> Option<u32>
pub fn pool_index(self) -> Option<u32>
Get the pool index for a composite type.
Returns None for primitive types.