pub struct ModuleRegistry { /* private fields */ }Expand description
Thread-safe registry for modules.
This registry allows concurrent lookups and insertions of imported modules during parallel function analysis. It uses double-checked locking to minimize contention.
Implementations
Sourceimpl ModuleRegistry
impl ModuleRegistry
Sourcepub fn get_or_create(
&self,
import_path: String,
file_path: String,
) -> (ModuleId, bool)
pub fn get_or_create( &self, import_path: String, file_path: String, ) -> (ModuleId, bool)
Get or create a module for the given import path and resolved file path.
Returns the ModuleId and whether it was newly created.
Sourcepub fn update_def(&self, id: ModuleId, def: ModuleDef)
pub fn update_def(&self, id: ModuleId, def: ModuleDef)
Update a module definition.